@@ -12,8 +12,8 @@ use regex::Regex;
 #[cfg(feature = "read_write")]
 use std::mem;
 
-#[cfg(feature = "diesel")]
-use crate::DieselConversionError;
+#[cfg(feature = "sql")]
+use crate::SqlConversionError;
 
 use std::convert::TryFrom;
 
@@ -82,7 +82,8 @@ impl Geo {
     }
 }
 
-#[cfg(feature = "diesel_support")]
+#[cfg(feature = "sql")]
+#[derive(Debug, Clone, Default)]
 pub(crate) struct AddressRaw {
     pub street: Option<String>,
     pub locality: Option<String>,
@@ -93,10 +94,20 @@ pub(crate) struct AddressRaw {
     pub geo_lat: Option<f64>,
 }
 
-#[cfg(feature = "diesel_support")]
+#[cfg(feature = "sql")]
+pub(crate) type AddressRawTuple = (
+        Option<String>,
+        Option<String>,
+        Option<String>,
+        Option<String>,
+        Option<String>,
+        (Option<f64>, Option<f64>),
+    );
+
+#[cfg(feature = "sql")]
 impl AddressRaw {
     /// Creates a new `AddressRaw`
-    pub(crate) fn new(
+    pub(crate) const fn new(
         street: Option<String>,
         locality: Option<String>,
         region: Option<String>,
@@ -117,20 +128,13 @@ impl AddressRaw {
     }
 }
 
-#[cfg(feature = "diesel_support")]
+#[cfg(feature = "sql")]
 impl Address {
-    /// Converts an address to something that can be used by a DieselContact.
+    /// Converts an address to something that can be used by a SqlContact.
     pub(crate) fn to_sql_raw(
-        this: Option<Self>,
-    ) -> (
-        Option<String>,
-        Option<String>,
-        Option<String>,
-        Option<String>,
-        Option<String>,
-        (Option<f64>, Option<f64>),
-    ) {
-        match this {
+        address: Option<Self>,
+    ) -> AddressRawTuple {
+        match address {
             None => (None, None, None, None, None, (None, None)),
             Some(adr) => (
                 adr.street,
@@ -147,13 +151,13 @@ impl Address {
     }
 }
 
-#[cfg(feature = "diesel_support")]
+#[cfg(feature = "sql")]
 impl AddressRaw {
     /// This should only be used internally.
     pub(crate) fn try_from_sql_raw(
         self,
         field_name: &'static str,
-    ) -> Result<Option<Address>, DieselConversionError> {
+    ) -> Result<Option<Address>, SqlConversionError> {
         let address = Address {
             // Set up the basic fields
             street: self.street,
@@ -178,29 +182,27 @@ impl AddressRaw {
                             ))
                         } else {
                             return Err(
-                                DieselConversionError::InvalidProperty(
-                                    String::from(format!(
+                                SqlConversionError::InvalidProperty(
+                                    format!(
                                         "Incomplete Geo in {}, \
                                             missing latitude",
                                         field_name
-                                    )),
+                                    ),
                                 ),
                             );
                         }
-                    } else {
-                        if self.geo_lat.is_some() {
+                    } else if self.geo_lat.is_some() {
                             return Err(
-                                DieselConversionError::InvalidProperty(
-                                    String::from(format!(
+                                SqlConversionError::InvalidProperty(
+                                    format!(
                                         "Incomplete Geo in {}, \
                                             missing longitude",
                                         field_name
-                                    )),
+                                    ),
                                 ),
                             );
-                        } else {
-                            None
-                        }
+                    } else {
+                        None
                     }
                 }
             },
