@@ -31,6 +31,12 @@ pub struct ContactInformation {
     DieselType = "Contack_contact_information_type",
     db_rename = "Contack_contact_information_type"
 )]
+#[cfg_attr(
+    feature = "sqlx",
+    derive(sqlx::Type),
+    sqlx(type_name = "CONTACK_CONTACT_INFORMATION_TYPE"),
+    sqlx(rename_all = "PascalCase")
+)]
 pub enum Type {
     Work,
     Home,
