@@ -55,15 +55,15 @@ pub struct DateTimeError(());
 
 // To Convert to Chrono UTC
 #[cfg(feature = "chrono")]
-impl Into<Option<chrono::NaiveDateTime>> for DateTime {
-    fn into(self) -> Option<chrono::NaiveDateTime> {
+impl From<DateTime> for Option<chrono::NaiveDateTime> {
+    fn from(them: DateTime) -> Self {
         NaiveDate::from_ymd_opt(
-            self.year.into(),
-            self.month.into(),
-            self.day.into(),
+            them.year,
+            them.month.into(),
+            them.day.into(),
         )
         .map(|x| {
-            x.and_hms(self.hour.into(), self.minute.into(), self.second.into())
+            x.and_hms(them.hour.into(), them.minute.into(), them.second.into())
         })
     }
 }
@@ -75,7 +75,7 @@ impl TryFrom<chrono::NaiveDateTime> for DateTime {
 
     fn try_from(dt: chrono::NaiveDateTime) -> Result<Self, Self::Error> {
         Ok(Self::new(
-            dt.year().try_into()?,
+            dt.year(),
             dt.month().try_into()?,
             dt.day().try_into()?,
             dt.hour().try_into()?,
