@@ -40,11 +40,11 @@
 //! 
 //!  * [VCard](https://crates.io/crates/vcard) `vcard`. Note this only support serialisation, and is a stricter alternative to the inbuilt `read_write`
 //!  * [Diesel](https://diesel.rs) `diesel_support`. This supports both serialisation and deserialisation.
-//! 
+//!  * [Sqlx](https://crates.io/crates/sqlx) `sqlx_support`. This supports both serialisation and deserialisation.
 //! 
 
 #![warn(clippy::all, clippy::pedantic, clippy::nursery, clippy::cargo)]
-#![allow(clippy::doc_markdown, clippy::module_name_repetitions)]
+#![allow(clippy::doc_markdown, clippy::module_name_repetitions, clippy::wildcard_imports, clippy::missing_const_for_fn, clippy::wrong_self_convention, clippy::missing_errors_doc)]
 
 pub mod address;
 pub mod contact_information;
@@ -64,25 +64,22 @@ extern crate lazy_static;
 #[cfg(feature = "diesel-derive-enum")]
 extern crate diesel_derive_enum;
 
-#[cfg(feature = "diesel_support")]
+#[cfg(feature = "diesel")]
 #[macro_use]
 extern crate diesel;
 
-#[cfg(feature = "diesel_support")]
+#[cfg(feature = "diesel_migrations")]
 #[macro_use]
 extern crate diesel_migrations;
 
 #[cfg(feature = "diesel_support")]
 pub mod schema;
 
-#[cfg(feature = "diesel_support")]
-pub mod diesel_support;
+#[cfg(feature = "sql")]
+pub mod sql;
 
-#[cfg(feature = "diesel_support")]
-use schema::*;
-
-#[cfg(feature = "diesel_support")]
-pub(crate) use diesel_support::DieselConversionError;
+#[cfg(feature = "sql")]
+pub(crate) use sql::SqlConversionError;
 
 #[cfg(feature = "read_write")]
 pub mod read_write;
