@@ -2,17 +2,19 @@ use contack::{
     address::{Address, Geo},
     contact_information::{ContactInformation, Type},
     contact_platform::ContactPlatform,
+    diesel_support::DieselContact,
     date_time::DateTime,
     name::Name,
     org::Org,
     schema,
     uri::Uri,
-    Contact, NewContact,
+    Contact
 };
 #[macro_use]
 extern crate diesel;
 extern crate dotenv;
 
+use std::convert::TryInto;
 use diesel::pg::PgConnection;
 use diesel::prelude::*;
 use dotenv::dotenv;
@@ -98,19 +100,12 @@ fn add_to_db() -> Result<(), Box<dyn std::error::Error>> {
     // Create a UUID for the contact.
     let uid = uuid::Uuid::new_v4().to_string();
 
-    // Create a `NewContact`, so that we can insert it into the database.
-    let new_contact: NewContact = NewContact::new(Name::new(
-        Some(String::from(String::from("John"))),
-        None,
-        Some(String::from(String::from("Doe"))),
-        None,
-        None,
-    ));
-
     // Create the proper contact
     let mut contact = create_a_contack();
     contact.uid = uid;
 
+    let contact: DieselContact = contact.try_into()?;
+
     // Insert it into the database
     diesel::insert_into(contacts::table)
         .values(&contact)
