@@ -4,7 +4,7 @@
 extern crate diesel;
 extern crate dotenv;
 
-use contack::diesel_contact::*;
+use contack::diesel_support::*;
 use contack::*;
 use diesel::pg::PgConnection;
 use diesel::prelude::*;
